@@ -1,4 +1,4 @@
-from ticket.api import TicketViewSet, MessageViewSet
+from badi_ticket.api import TicketViewSet, MessageViewSet
 from .views import *
 
 from rest_framework.routers import DefaultRouter
@@ -7,6 +7,3 @@ router = DefaultRouter()
 router.register('ticket', TicketViewSet, basename='ticket')
 router.register('message', MessageViewSet, basename='message')
 urlpatterns = router.urls
-
-
-
